A Python library that implements ElsieFour (LC4) encryption, based on the algorithm in
(Kaminsky 2017).

Features
--------

- Support for custom alphabets
- An `interactive command-line utility <https://github.com/dstein64/LC4/blob/master/documentation.md#interactive-command-line-utility>`__

Requirements
------------

LC4 supports Python 2.7 and Python 3.x.

Linux, Mac, and Windows are supported.

Other operating systems may be compatible if NumPy can be properly installed.

Installation
------------

`LC4 <https://pypi.python.org/pypi/lc4>`__ is available on PyPI, the Python Package Index.

::

    $ pip install lc4

Documentation
-------------

See `documentation.md <https://github.com/dstein64/LC4/blob/master/documentation.md>`__.

Example Usage
-------------

See `example.py <https://github.com/dstein64/LC4/blob/master/example.py>`__.

License
-------

The code in this repository has an `MIT License <https://en.wikipedia.org/wiki/MIT_License>`__.

See `LICENSE <https://github.com/dstein64/LC4/blob/master/LICENSE>`__.

References
----------

Kaminsky, Alan. “ElsieFour: A Low-Tech Authenticated Encryption Algorithm
For Human-to-Human Communication,” 2017. https://eprint.iacr.org/2017/339.
